import React, { useState } from "react"
import { Divider, Image, Modal, Space, theme } from 'antd'
import play from "../../../public/image/play.png"
import style from './index.less'
import { getVideoImgUrl } from "@/utils"
import { CloseOutlined } from "@ant-design/icons"

interface Props {
    urlList: string[]
}
const LookVideo: React.FC<Props> = ({ urlList = [] }) => {

    /***************************/
    const { useToken } = theme;
    const { token } = useToken()
    const [count, setCount] = useState<number>(0)
    const [toPlay, setToPlay] = useState<boolean>(false)
    /***************************/

    return urlList.length > 0 ? <div style={{ display: 'inline-block' }}>
        <div className={style.imgNews} style={{ borderRadius: token.borderRadius }}>
            <Image src={urlList[0] ? getVideoImgUrl(urlList[0]) : 'error'} preview={false} className={style.img} />
            <div className={style.mask}>
                <img src={play} onClick={(e) => { e.stopPropagation(); setToPlay(true) }} />
            </div>
        </div>
        {toPlay && <div onClick={(e) => { e.stopPropagation(); }}>
            <Modal
                open={toPlay}
                styles={{ body: { backgroundColor: 'rgba(0,0,0,0.8)', overflow: 'hidden', borderRadius: token.borderRadius, padding: '20px 24px' } }}
                footer={null}
                closeIcon={<CloseOutlined style={{ color: token.colorPrimary }} />}
                onCancel={(e) => { e.stopPropagation(); setToPlay(false) }}
                className="playVideo"
            >
                <Space wrap>
                    {urlList.map((url, index) => <div className={style.imgNews} key={index} style={{ borderRadius: token.borderRadius, boxShadow: count === index ? `0px 0px 0px 1px #FFF` : 'none' }}>
                        <Image src={urlList[0] ? getVideoImgUrl(urlList[index]) : 'error'} preview={false} className={style.imgList} />
                        <div className={style.mask}>
                            <img src={play} onClick={(e) => { e.stopPropagation(); setCount(index) }} />
                        </div>
                    </div>)}
                </Space>
                <Divider dashed/>
                <video className={style.video} style={{ borderRadius: token.borderRadius }} src={urlList[count]} autoPlay controls>您的浏览器不支持 video 标签。</video>
            </Modal>
        </div>}
    </div> : '无素材'
}

export default React.memo(LookVideo)