import React, { useState } from "react"
import { Button, Flex, Image, Space, Typography } from 'antd'
import { RatioEnum } from "@/const"

interface Props {
    claimJson: string,
    items?: string[],
    resourceUrl?: string
}
const Material: React.FC<Props> = ({ items = [], resourceUrl, claimJson }) => {

    /******************************/
    const [visible, setVisible] = useState<boolean>(false)
    const { size, extent } = JSON.parse(claimJson)
    /******************************/

    return <>
        <Flex vertical={true}>
            <Typography.Title level={5}>素材制作要求</Typography.Title>
            <Typography.Text>素材尺寸：{size?.[0]} * {size?.[1]}</Typography.Text>
            <Typography.Text>素材大小：{extent?.[0]}MB ~ {extent?.[1]}MB</Typography.Text>
        </Flex>

        <Space>
            {items.length > 0 && <>
                <Image.PreviewGroup
                    items={items}
                    preview={{
                        visible: visible,
                        onVisibleChange: (value) => {
                            setVisible(value);
                        },
                    }}
                />
                <Button type="link" style={{ padding: 0 }} onClick={() => setVisible(true)}>素材示例</Button>
            </>}
            {resourceUrl && <Button type="link" style={{ paddingLeft: 0, paddingRight: 0 }} href={resourceUrl} download="资源包下载">资源包下载</Button>}
        </Space>

    </>
}

export default React.memo(Material)