import LookVideo from "@/components/LookVideo";
import { Flex, Typography } from "antd";
import { ColumnsType } from "antd/es/table";
import React from "react";


const Columns = (): ColumnsType<any> => {
    let arr: ColumnsType<any> = [
        {
            title: '素材预览',
            dataIndex: 'materialLinkList',
            key: 'materialLinkList',
            align: 'center',
            width: 120,
            render: (a, b) => {
                return <LookVideo urlList={a} />
            }
        },
        {
            title: '制作者',
            dataIndex: 'userName',
            key: 'userName',
            align: 'center',
            width: 90
        },
        {
            title: '上传时间',
            dataIndex: 'createTime',
            key: 'createTime',
            align: 'center',
            width: 120
        },
        {
            title: '上传任务名称',
            dataIndex: 'taskName',
            key: 'taskName',
            align: 'center',
            width: 120,
            render(value) {
                return <Typography.Paragraph style={{ marginBottom: 0 }} ellipsis={{ rows: 3 }}>{value}</Typography.Paragraph>
            },
        },
        {
            title: '素材规格',
            dataIndex: 'materialClaimJson',
            key: 'materialClaimJson',
            width: 150,
            render(value) {
                if (value) {
                    const { size, extent } = JSON.parse(value)
                    return <Flex vertical={true}>
                        <Typography.Text>素材尺寸：{size?.[0]} * {size?.[1]}</Typography.Text>
                        <Typography.Text>素材大小：{extent?.[0]}MB ~ {extent?.[1]}MB</Typography.Text>
                    </Flex>
                } else {
                    return '--'
                }
            },
        },
        {
            title: '素材审核',
            dataIndex: 'checkStatus',
            key: 'checkStatus',
            align: 'center',
            width: 100,
            render(value) {
                return (value || value === 0) ? value : '--'
            },
        },
        {
            title: '素材奖励结算',
            dataIndex: 'checkoutType',
            key: 'checkoutType',
            align: 'center',
            width: 100,
            render(value, record) {
                return <span>{value === 'CHECKOUT_TYPE_SCALE' ? `总消耗 ${record.checkout * 100}%` : `${record.checkout}元（审核合格）`}</span>
            },
        },
        {
            title: '素材总消耗',
            dataIndex: 'cost',
            key: 'cost',
            align: 'center',
            width: 100,
            render(value) {
                return (value || value === 0) ? value : '--'
            },
        },
        {
            title: '收益',
            dataIndex: 'income',
            key: 'income',
            align: 'center',
            fixed: 'right',
            width: 100,
            render(value) {
                return (value || value === 0) ? value : '--'
            },
        },
    ]

    return arr
}

export default Columns