import { SearchOutlined } from "@ant-design/icons"
import { PageContainer } from "@ant-design/pro-components"
import { useRequest, useSize } from "ahooks";
import { Affix, Avatar, Image, Button, Card, Col, Flex, Form, Input, List, Row, Space, Tag, Typography, theme, DatePicker, Select, Tooltip } from "antd"
import { useEffect, useRef, useState } from "react";
import TaskModal from "./taskModal";
import { getTaskListApi } from "@/services/task-api/myTask";
import { MaterialSourceEnum, MaterialTypeEle, MaterialTypeEnum, StatusEnum, TaskStatusEle, TaskTypeEle, TaskTypeEnum, UrgencyEnum } from "@/const";
import Material from "@/components/Material";
import moment from "moment";

/**
 * 我的任务
 * @returns 
 */
const MyTask: React.FC = () => {


    /***********************************/
    const { useToken } = theme;
    const ref = useRef(null);
    const size = useSize(ref)
    const { token } = useToken();
    const [form] = Form.useForm()
    const [initialValues, setInitialState] = useState<any>({})
    const [visible, setVisible] = useState<boolean>(false)
    const [queryForm, setQueryForm] = useState<TASKAPI.TaskList>({ pageNum: 1, pageSize: 10 })
    const getTaskList = useRequest(getTaskListApi, { manual: true })//添加请求
    /***********************************/

    useEffect(() => {
        getTaskList.run(queryForm)
    }, [queryForm])

    const onFinish = (data: any) => {
        const { time, ...pre } = data
        let newQueryForm = JSON.parse(JSON.stringify(queryForm))
        newQueryForm.pageNum = 1
        if (time) {
            newQueryForm.startTime = moment(time[0]).format('YYYY-MM-DD')
            newQueryForm.endTime = moment(time[1]).format('YYYY-MM-DD')
        } else {
            delete newQueryForm?.startTime
            delete newQueryForm?.endTime
        }
        setQueryForm({ ...newQueryForm, ...pre })
    }

    const editHandle = (data: any) => {
        console.log(data)
        let newData: any ={}
        const { startTime, endTime, materialClaimJson, materialExample, checkoutType, checkout, urgency, ...pre } = data
        if (checkoutType === 'CHECKOUT_TYPE_SCALE') {
            newData['checkout'] = checkout * 100
        } else {
            newData['checkout'] = checkout
        }
        newData['endTime'] = endTime ? moment(endTime) : null
        newData['materialExamples'] = materialExample ? materialExample.split(',') : []
        setInitialState({ ...newData, ...pre, ...JSON.parse(materialClaimJson), checkoutType, startTime: moment(startTime), urgency: urgency + '' })
        setVisible(true)
    }

    return <PageContainer>
        <Card
            style={{
                borderRadius: 8,
            }}
            bodyStyle={{
                paddingTop: 0,
                paddingLeft: 0,
                paddingRight: 0
            }}
            ref={ref}
        >
            <Space direction="vertical" style={{ width: '100%' }} size={0}>
                <Affix offsetTop={56}>
                    <div style={{ backgroundColor: token.colorBgBase, padding: token.paddingContentHorizontalLG, borderRadius: 8, borderBottom: `1px solid ${token.colorBorderSecondary}` }}>
                        <Form layout="inline" className='queryForm' name="basic" form={form} onFinish={onFinish}>
                            <Row gutter={[0, 6]}>
                                <Col>
                                    <Form.Item name='name'>
                                        <Input prefix={<SearchOutlined />} placeholder="任务名称" />
                                    </Form.Item>
                                </Col>

                                <Col><Form.Item name='time'>
                                    <DatePicker.RangePicker style={{ width: 250 }} placeholder={['发布开始日期', '发布开始日期']} />
                                </Form.Item></Col>

                                <Col><Form.Item name='taskType'>
                                    <Select
                                        placeholder="任务分类"
                                        style={{ width: 100 }}
                                        allowClear
                                        options={Object.keys(TaskTypeEnum).map(key => ({ label: (TaskTypeEnum as any)[key], value: key }))}
                                    />
                                </Form.Item></Col>

                                <Col><Form.Item name='status'>
                                    <Select
                                        placeholder="任务状态"
                                        style={{ width: 100 }}
                                        allowClear
                                        options={Object.keys(StatusEnum).map(key => ({ label: (StatusEnum as any)[key], value: key }))}
                                    />
                                </Form.Item></Col>

                                <Col><Form.Item name='urgency'>
                                    <Select
                                        placeholder="任务紧急度"
                                        style={{ width: 120 }}
                                        allowClear
                                        options={Object.keys(UrgencyEnum).map(key => ({ label: (UrgencyEnum as any)[key], value: key }))}
                                    />
                                </Form.Item></Col>

                                <Col><Form.Item name='materialType'>
                                    <Select
                                        placeholder="素材类型"
                                        style={{ width: 100 }}
                                        allowClear
                                        options={Object.keys(MaterialTypeEnum).map(key => ({ label: (MaterialTypeEnum as any)[key], value: key }))}
                                    />
                                </Form.Item></Col>

                                <Col><Form.Item name='materialSource'>
                                    <Select
                                        placeholder="素材来源"
                                        style={{ width: 100 }}
                                        allowClear
                                        options={Object.keys(MaterialSourceEnum).map(key => ({ label: (MaterialSourceEnum as any)[key], value: key }))}
                                    />
                                </Form.Item></Col>

                                <Col>
                                    <Space>
                                        <Button type="primary" htmlType="submit">搜索</Button>
                                        <Button onClick={() => form.resetFields()}>重置</Button>
                                        <Button type="primary" onClick={() => { setInitialState({}); setVisible(true) }}>发布素材任务</Button>
                                    </Space>
                                </Col>
                            </Row>
                        </Form>

                    </div>
                </Affix>

                <List
                    itemLayout="vertical"
                    size="large"
                    dataSource={getTaskList.data?.data?.records}
                    loading={getTaskList.loading}
                    pagination={{
                        onChange: (page) => {
                            console.log(page);
                            setQueryForm({ ...queryForm, pageNum: page })
                        },
                        current: queryForm.pageNum,
                        pageSize: queryForm.pageSize,
                    }}
                    renderItem={(item: any, index) => (
                        <List.Item
                            key={item.id}
                            extra={<Flex gap={20} style={{ height: '100%' }}>
                                <Flex style={{ width: size?.width ? `${size?.width / 2 - 265}px` : 300 }} vertical={true} align="flex-start" justify="space-between">
                                    <Material items={item?.materialExample?.split(',')} resourceUrl={item.materialResource} claimJson={item.materialClaimJson} />
                                </Flex>
                                <Flex style={{ width: 165, height: '100%' }} gap={10} vertical={true} align="center" justify="center">
                                    {TaskStatusEle[item.status]}
                                    <Tag color="error">结算：{item.checkoutType === 'CHECKOUT_TYPE_SCALE' ? `总消耗 ${item.checkout * 100}%` : `${item.checkout}元（审核合格）`}</Tag>
                                    <Button type="primary" onClick={() => editHandle(item)}>修改任务</Button>
                                </Flex>
                            </Flex>}
                            actions={[
                                <Tooltip title='发布时间'><span>{item.createTime}</span></Tooltip>,
                                <Tooltip title='任务分类'>{TaskTypeEle[item.taskType]}</Tooltip>,
                                <Tooltip title='素材类型'>{MaterialTypeEle[item.materialType]}</Tooltip>,
                                <Tooltip title='素材来源要求'><Tag>{(MaterialSourceEnum as any)[item.materialSource]}</Tag></Tooltip>
                            ]}
                        >
                            <List.Item.Meta
                                avatar={<Avatar src={item.avatar || `https://xsgames.co/randomusers/avatar.php?g=pixel&key=${index}`} style={{ backgroundColor: '#87d068' }} />}
                                title={<Space size={20}>
                                    <Typography.Title level={5} style={{ marginBottom: 0 }}>{item.name}</Typography.Title>
                                    {!!item.urgency && <Space size={4}><span style={{ color: 'red' }}>置顶</span>🆙</Space>}
                                </Space>}
                                description={<Space direction="vertical" style={{ width: '100%' }} size={0}>
                                    {/* 有效时间 */}
                                    <Typography.Text type="secondary" ellipsis>任务有效时间：{item.startTime}~{item.endTime ? item.endTime : '长期有效'}</Typography.Text>
                                    {/* 任务描述 */}
                                    {item.remark && <Typography.Text type="secondary" ellipsis={{ tooltip: true }}>{item.remark}</Typography.Text>}
                                </Space>}
                            />
                            <Typography.Paragraph ellipsis={{ rows: 3, tooltip: true }} style={{ marginBottom: 0 }}>{item.remarkMore}</Typography.Paragraph>
                        </List.Item>
                    )}
                />
            </Space>

            {visible && <TaskModal visible={visible} onClose={() => setVisible(false)} onChange={() => { setVisible(false); getTaskList.refresh() }} initialValues={initialValues} />}
        </Card>
    </PageContainer>
}

export default MyTask