import { RcFile } from "antd/es/upload";
import SparkMD5 from "spark-md5";

/** 获取base64 */
export const getBase64 = (file: RcFile, callback: (url: string) => void) => {
    const reader = new FileReader();
    reader.addEventListener('load', () => callback(reader.result as string));
    reader.readAsDataURL(file);
};

/** 获取图片上传宽高 */
export const getImgSizeProper = (file: RcFile): Promise<void> => {
    return new Promise((resolve: (value: any | PromiseLike<void>) => void) => {
        let img: any = new Image();
        let _URL = window.URL || window.webkitURL;
        img.onload = function (e: any) {
            resolve({ width: this.width, height: this.height })
        }
        img.src = _URL.createObjectURL(file);
    })
}


/* 获取视频宽高*/
export const videoMessage = (videos: RcFile[]): Promise<{ width: number, height: number, videoLength: number }[]> => {
    return new Promise((resolve, reject) => {
        if (videos.length > 0) {
            let videoAll = videos?.map((item: RcFile) => {
                return new Promise((resolve) => {
                    var videoUrl = URL.createObjectURL(item);
                    var videoObj = document.createElement("video");
                    videoObj.onloadedmetadata = function (evt) {
                        URL.revokeObjectURL(videoUrl);
                        // 执行上传的方法，获取外网路径，上传进度等
                        resolve({ width: videoObj.videoWidth, height: videoObj.videoHeight, videoLength: videoObj.duration })
                    };
                    videoObj.src = videoUrl;
                    videoObj.load();
                })
            })
            Promise.all(videoAll).then((res: any) => {
                resolve(res)
            })
        } else {
            reject([])
        }
    })
};

/**
 * 获取素材MD5
 * @param file 
 * @returns 
 */
export const getMD5 = (file: RcFile): Promise<string> => {
    return new Promise(resolve => {
        let spark = new SparkMD5();
        let fileReader = new FileReader();
        fileReader.readAsBinaryString(file);
        fileReader.onload = function (e: any) {
            spark.appendBinary(e.target.result);
            let md5 = spark.end()
            resolve(md5)
        }
    })
}

/**
 * 拼接oss参数获取视频首针图
 * @param videoUrl 
 */
export const getVideoImgUrl = (videoUrl: string) => {
    return videoUrl + "?x-oss-process=video/snapshot,t_0,f_jpg,w_0,h_0,m_fast,ar_auto"
}